import type { APIContext, ComponentInstance, MiddlewareHandler, RouteData } from '../@types/astro.js';
import { AstroCookies } from './cookies/index.js';
import { type Pipeline } from './render/index.js';
export declare class RenderContext {
    #private;
    readonly pipeline: Pipeline;
    locals: App.Locals;
    readonly middleware: MiddlewareHandler;
    readonly pathname: string;
    readonly request: Request;
    readonly routeData: RouteData;
    status: number;
    readonly cookies: AstroCookies;
    readonly params: import("../@types/astro.js").Params;
    readonly url: URL;
    private constructor();
    static create({ locals, middleware, pathname, pipeline, request, routeData, status, }: Pick<RenderContext, 'pathname' | 'pipeline' | 'request' | 'routeData'> & Partial<Pick<RenderContext, 'locals' | 'middleware' | 'status'>>): RenderContext;
    /**
     * The main function of the RenderContext.
     *
     * Use this function to render any route known to Astro.
     * It attempts to render a route. A route can be a:
     *
     * - page
     * - redirect
     * - endpoint
     * - fallback
     */
    render(componentInstance: ComponentInstance | undefined): Promise<Response>;
    createAPIContext(props: APIContext['props']): APIContext;
    createResult(mod: ComponentInstance): Promise<import("../@types/astro.js").SSRResult>;
    computeCurrentLocale(): string | undefined;
    computePreferredLocale(): string | undefined;
    computePreferredLocaleList(): string[] | undefined;
}
